# tis-disable-microsoft-office-telemetry


# -*- coding: utf-8 -*-
##################################################
# This file is part of WAPT Enterprise
# All right reserved, (c) Tranquil IT Systems 2024
# For more information please refer to
# https://wapt.tranquil.it/store/licences.html
##################################################
from setuphelpers import *
from waptservice.enterprise import get_active_sessions, start_interactive_process
import win32ts
import win32security

""" 
https://admx.help/?Category=Office2016&Policy=office16.Office.Microsoft.Policies.Windows::L_OfficeExperiencesAnlayzingContent
https://admx.help/?Category=Office2016&Policy=office16.Office.Microsoft.Policies.Windows::L_SendTelemetry&Language=fr-fr

"""


def install():
    pass


def session_setup():
    # Only admins can write in: HKEY_CURRENT_USER\SOFTWARE\Policies
    # registry_set(HKEY_CURRENT_USER, r"software\policies\microsoft\office\common\clienttelemetry", "sendtelemetry", 3)
    # registry_set(HKEY_CURRENT_USER, r"software\policies\microsoft\office\16.0\common\privacy", "usercontentdisabled", 2)

    wapt_get_path = makepath(WAPT.wapt_base_dir, "wapt-get.exe")
    print(run([wapt_get_path, "audit", control.package, "-f"]))
    # WAPT.audit(control.package, force=True)  # Do not use since WAPT service will be busy


def audit():
    audit_status = "OK"
    for session_id in get_active_sessions():
        # username = win32ts.WTSQuerySessionInformation(win32ts.WTS_CURRENT_SERVER_HANDLE, session_id, win32ts.WTSUserName)
        user_sid = get_user_sid_from_session_id(session_id)
        full_username = get_user_from_sid(user_sid)
        print(f"Applying: {control.package} for: {full_username}")
        registry_set(HKEY_USERS, rf"{user_sid}\software\policies\microsoft\office\common\clienttelemetry", "sendtelemetry", 3)
        registry_set(HKEY_USERS, rf"{user_sid}\software\policies\microsoft\office\16.0\common\privacy", "usercontentdisabled", 2)

    return audit_status


def get_user_sid_from_session_id(session_id):
    try:
        user_name = win32ts.WTSQuerySessionInformation(win32ts.WTS_CURRENT_SERVER_HANDLE, session_id, win32ts.WTSUserName)
        if user_name:
            user_sid = win32security.ConvertSidToStringSid(win32security.LookupAccountName(None, user_name)[0])
            return user_sid
    except Exception as e:
        print(f"Error getting SID for session {session_id}: {e}")
        raise
